##-*- Mode: CPerl -*-

## File: Pd/Patch/atom.pm
## Author: Bryan Jurish <moocow@ling.uni-potsdam.de>
## Description:
##  + class for Pd canvas atoms (msg, floatatom, symbolatom, ...)
##======================================================================

use strict;

##======================================================================
## atom: generic
package Pd::Patch::atom;
use Pd::Patch::Item;
our @ISA = qw(Pd::Patch::Item);
sub PROPERTIES { return [qw(decl type x y)]; }
sub DEFAULTS { return {decl=>'#X', type=>'msg', 'x'=>0, 'y'=>0}; }
__PACKAGE__->init();

##======================================================================
## msg: message box
package Pd::Patch::X_msg;
our @ISA = qw(Pd::Patch::atom);
sub PROPERTIES { return [qw(decl type x y msg)]; }
sub DEFAULTS { return {decl=>'#X', type=>'msg', 'x'=>0, 'y'=>0, msg=>''}; }
__PACKAGE__->init();

##-- aliases
@Pd::Patch::msg::ISA = (__PACKAGE__);
@Pd::Patch::Message::ISA = (__PACKAGE__);

##======================================================================
## floatatom: float atom
##
## labelpos: 0=left, 1=right, 2=top, 3=bottom
## label,send,recv: -=none
package Pd::Patch::X_floatatom;
our @ISA = qw(Pd::Patch::atom);
sub PROPERTIES { return [qw(decl type x y width lo hi labelpos label recv send)]; }
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'floatatom', 'x'=>0, 'y'=>0,
	  width=>5, lo=>0, hi=>0, labelpos=>0, label=>'-', recv=>'-', send=>'-',
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::floatatom::ISA = (__PACKAGE__);
@Pd::Patch::Number::ISA = (__PACKAGE__);


##======================================================================
## symbolatom: symbol atom
package Pd::Patch::X_symbolatom;
our @ISA = qw(Pd::Patch::atom);
*PROPERTIES = \*Pd::Patch::X_floatatom::PROPERTIES;
*DEFAULTS   = \*Pd::Patch::X_floatatom::DEFAULTS;
__PACKAGE__->init();

##-- aliases
@Pd::Patch::symbolatom::ISA = (__PACKAGE__);
@Pd::Patch::Symbol::ISA = (__PACKAGE__);

##======================================================================
## text: comment text
package Pd::Patch::X_text;
our @ISA = qw(Pd::Patch::atom);
sub PROPERTIES { return [qw(decl type x y text)]; } ##-- remaining args: comment text
sub DEFAULTS { return {decl=>'#X', type=>'text', 'x'=>0, 'y'=>0, text=>'comment'}; }
__PACKAGE__->init();

##-- aliases
@Pd::Patch::text::ISA = (__PACKAGE__);
@Pd::Patch::comment::ISA = (__PACKAGE__);
@Pd::Patch::Comment::ISA = (__PACKAGE__);

##-- new methods

## $text = $cmt->text()
sub text {
  my $cmt = shift;
  return join(' ', @{$cmt->{_pd}}[$cmt->PROPERTIES_byname->{text}..$#{$cmt->{_pd}}]);
}

## $cmt = $cmt->escape()
##  + try to escape symbols
sub escape {
  my $cmt = shift;
  my $text = $cmt->text();
  $text =~ s/,/ \\,/g;
  @{$cmt->{_pd}}[$cmt->PROPERTIES_byname->{text}..$#{$cmt->{_pd}}] = qw();
  $cmt->configure(text=>$text);
  return $cmt;
}

1; ##-- be happy

__END__

##======================================================================
## Docs
=pod

=head1 NAME

Pd::Patch - Perl parser and wrapper classes for Pd abstractions

=head1 SYNOPSIS

 use Pd::Patch;

 #... stuff happens...

=cut

##======================================================================
## Description
=pod

=head1 DESCRIPTION

not yet written

=cut

##======================================================================
## Footer
=pod

=head1 ACKNOWLEDGEMENTS

perl by Larry Wall.

Pd by Miller Puckette and others.

=head1 AUTHOR

Bryan Jurish E<lt>moocow@ling.uni-potsdam.deE<gt>

=head1 COPYRIGHT

Copyright (c) 2007, Bryan Jurish.  All rights reserved.

This package is free software.  You may redistribute it
and/or modify it under the same terms as Perl itself.

=head1 SEE ALSO

perl(1),
pd(1).

=cut
