##-*- Mode: CPerl -*-

## File: Pd/Patch/gui.pm
## Author: Bryan Jurish <moocow@ling.uni-potsdam.de>
## Description:
##  + class for common Pd canvas GUI objects
##======================================================================

##======================================================================
## gui: generic
package Pd::Patch::gui;
use Pd::Patch::obj;
our @ISA = ('Pd::Patch::X_obj');


##======================================================================
## obj: bng (gui bang)
package Pd::Patch::bng;
our @ISA = qw(Pd::Patch::gui);
sub PROPERTIES {
  return [
	  qw(decl type x y name),
	  qw(size hold interrupt init),
	  qw(send recv),
	  qw(label xoffset yoffset font fontsize),
	  qw(bg fg labcolor), #)
	 ];
}
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'obj', 'x'=>0, 'y'=>0, name=>'bng',
	  size=>15, hold=>250, interrupt=>50, init=>0,
	  send=>'empty', recv=>'empty',
	  label=>'empty', xoffset=>17, yoffset=>7,
	  font=>0, fontsize=>10,         ##-- font: 0=courier, 1=helvetica, 2=times
	  bg=>0, fg=>-1, labelcolor=>-1, ##-- either rgb (< 0) or preset (0..29): 0=white, -1=black
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::Bang::ISA    = (__PACKAGE__);


##======================================================================
## obj: tgl (gui toggle)
package Pd::Patch::tgl;
our @ISA = qw(Pd::Patch::gui);
sub PROPERTIES {
  return [
	  qw(decl type x y name),
	  qw(size init),
	  qw(send recv),
	  qw(label xoffset yoffset font fontsize),
	  qw(bg fg labelcolor), #)
	  qw(unknown value),
	 ];
}
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'obj', 'x'=>0, 'y'=>0, name=>'tgl',
	  size=>15, init=>0,
	  send=>'empty', recv=>'empty',
	  label=>'empty', xoffset=>17, yoffset=>7,
	  font=>0, fontsize=>10,         ##-- font: 0=courier, 1=helvetica, 2=times
	  bg=>0, fg=>-1, labelcolor=>-1, ##-- either rgb (< 0) or preset (0..29): 0=white, -1=black
	  unknown=>0, value=>1,
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::Toggle::ISA = (__PACKAGE__);


##======================================================================
## obj: nbx (gui Number2)
package Pd::Patch::nbx;
our @ISA = qw(Pd::Patch::gui);
sub PROPERTIES {
  return [
	  qw(decl type x y name),
	  qw(width height),
	  qw(min max linlog init),
	  qw(send recv),
	  qw(label xoffset yoffset font fontsize),
	  qw(bg fg labelcolor), #)
	  qw(value logheight),
	 ];
}
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'obj', 'x'=>0, 'y'=>0, name=>'nbx',
	  width=>5, height=>14,
	  min=>'-1e+37', max=>'1e+37',
	  linlog=>0, init=>0, ##-- linlog: 0=lin, 1=log
	  send=>'empty', recv=>'empty',
	  label=>'empty', xoffset=>0, yoffset=>-8,
	  font=>0, fontsize=>10,
	  bg=>0, fg=>-1, labelcolor=>-1,
	  value=>'0', logheight=>256,
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::Number2::ISA = (__PACKAGE__);


##======================================================================
## obj: vsl (gui Vslider)
package Pd::Patch::vsl;
our @ISA = qw(Pd::Patch::gui);
sub PROPERTIES {
  return [
	  qw(decl type x y name),
	  qw(width height),
	  qw(min max),
	  qw(linlog init), ##-- linlog: 0=lin, 1=log
	  qw(send recv),
	  qw(label xoffset yoffset font fontsize),
	  qw(bg fg labelcolor), #)
	  qw(cvalue onclick), ##-- cvalue=value*100; onclick: 0=jump, 1=steady
	 ];
}
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'obj', 'x'=>0, 'y'=>0, name=>'vsl',
	  width=>15, height=>128,
	  min=>'0', max=>'127',
	  linlog=>0, init=>0, ##-- linlog: 0=lin, 1=log
	  send=>'empty', recv=>'empty',
	  label=>'empty', xoffset=>0, yoffset=>-9,
	  font=>0, fontsize=>10,
	  bg=>0, fg=>-1, labelcolor=>-1,
	  value=>'0', onclick=>'1',
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::Vslider::ISA = (__PACKAGE__);

##======================================================================
## obj: hsl (gui Hslider)
package Pd::Patch::hsl;
our @ISA = qw(Pd::Patch::gui);
sub PROPERTIES {
  return [
	  qw(decl type x y name),
	  qw(width height),
	  qw(min max),
	  qw(linlog init), ##-- linlog: 0=lin, 1=log
	  qw(send recv),
	  qw(label xoffset yoffset font fontsize),
	  qw(bg fg labelcolor), #)
	  qw(cvalue onclick), ##-- cvalue=value*100; onclick: 0=jump, 1=steady
	 ];
}
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'obj', 'x'=>0, 'y'=>0, name=>'hsl',
	  width=>128, height=>15,
	  min=>'0', max=>'127',
	  linlog=>0, init=>0, ##-- linlog: 0=lin, 1=log
	  send=>'empty', recv=>'empty',
	  label=>'empty', xoffset=>-2, yoffset=>-8,
	  font=>0, fontsize=>10,
	  bg=>0, fg=>-1, labelcolor=>-1,
	  value=>'0', onclick=>'1',
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::Hslider::ISA = (__PACKAGE__);


##======================================================================
## obj: vradio (gui Vradio)
package Pd::Patch::vradio;
our @ISA = qw(Pd::Patch::gui);
sub PROPERTIES {
  return [
	  qw(decl type x y name),
	  qw(size unknown1 init number),
	  qw(send recv),
	  qw(label xoffset yoffset font fontsize),
	  qw(bg fg labelcolor), #)
	  qw(value),
	 ];
}
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'obj', 'x'=>0, 'y'=>0, name=>'vradio',
	  size=>15,
	  unknown1=>1, ##-- ??
	  init=>0,
	  number=>8, ##-- number of choices
	  send=>'empty', recv=>'empty',
	  label=>'empty', xoffset=>0, yoffset=>-8,
	  font=>0, fontsize=>10,
	  bg=>0, fg=>-1, labelcolor=>-1,
	  value=>0, ##-- currently selected
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::Vradio::ISA = (__PACKAGE__);

##======================================================================
## obj: hradio (gui Hradio)
package Pd::Patch::hradio;
our @ISA = qw(Pd::Patch::vradio);
sub DEFAULTS {
  return {
	  %{Pd::Patch::vradio->DEFAULTS}, name=>'hradio'
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::Hradio::ISA = (__PACKAGE__);

##======================================================================
## obj: vu (gui VU)
package Pd::Patch::vu;
our @ISA = qw(Pd::Patch::gui);
sub PROPERTIES {
  return [
	  qw(decl type x y name),
	  qw(width height),
	  qw(recv label xoffset yoffset font fontsize),
	  qw(bg labelcolor), #)
	  qw(scale unknown1),
	 ];
}
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'obj', 'x'=>0, 'y'=>0, name=>'vu',
	  width=>15, height=>120,
	  recv=>'empty',
	  label=>'empty', xoffset=>-1, yoffset=>-8,
	  font=>0, fontsize=>8,
	  bg=>-66577, labelcolor=>-1,
	  scale=>0, ##-- 0=no_scale, 1=scale
	  unknown1=>0,
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::VU::ISA = (__PACKAGE__);

##======================================================================
## obj: cnv (gui canvas)
package Pd::Patch::cnv;
our @ISA = qw(Pd::Patch::gui);
sub PROPERTIES {
  return [
	  qw(decl type x y name),
	  qw(size width height),
	  qw(send recv),
	  qw(label xoffset yoffset font fontsize),
	  qw(bg labelcolor), #)
	  qw(unknown1),
	 ];
}
sub DEFAULTS {
  return {
	  decl=>'#X', type=>'obj', 'x'=>0, 'y'=>0, name=>'cnv',
	  size=>15, ##-- selectable size
	  width=>100, height=>60,
	  send=>'empty', recv=>'empty', label=>'empty',
	  xoffset=>20, yoffset=>12,
	  font=>0, fontsize=>14,
	  bg=>-233017, labelcolor=>-66577,
	  unknown1=>0,
	 };
}
__PACKAGE__->init();

##-- aliases
@Pd::Patch::VU::ISA = (__PACKAGE__);



1; ##-- be happy

__END__

##======================================================================
## Docs
=pod

=head1 NAME

Pd::Patch - Perl parser and wrapper classes for Pd abstractions

=head1 SYNOPSIS

 use Pd::Patch;

 #... stuff happens...

=cut

##======================================================================
## Description
=pod

=head1 DESCRIPTION

not yet written

=cut

##======================================================================
## Footer
=pod

=head1 ACKNOWLEDGEMENTS

perl by Larry Wall.

Pd by Miller Puckette and others.

=head1 AUTHOR

Bryan Jurish E<lt>moocow@ling.uni-potsdam.deE<gt>

=head1 COPYRIGHT

Copyright (c) 2007, Bryan Jurish.  All rights reserved.

This package is free software.  You may redistribute it
and/or modify it under the same terms as Perl itself.

=head1 SEE ALSO

perl(1),
pd(1).

=cut
